@@ -20,8 +20,7 @@
  *     Jonas Ådahl <jadahl@gmail.com>
  */
 
-#ifndef GRD_CONTEXT_H
-#define GRD_CONTEXT_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -64,5 +63,3 @@ GrdEglThread * grd_context_get_egl_thread (GrdContext *context);
 GrdRuntimeMode grd_context_get_runtime_mode (GrdContext *context);
 
 void grd_context_notify_daemon_ready (GrdContext *context);
-
-#endif /* GRD_CONTEXT_H */
