@@ -104,6 +104,7 @@ peek_bytes (int            fd,
           g_set_error (error, G_IO_ERROR,
                        g_io_error_from_errno (errno),
                        "On poll command: %s", strerror (errno));
+          g_cancellable_release_fd (cancellable);
           return FALSE;
         }
 
@@ -111,6 +112,7 @@ peek_bytes (int            fd,
         {
           g_set_error (error, G_IO_ERROR, G_IO_ERROR_CANCELLED,
                        "Cancelled");
+          g_cancellable_release_fd (cancellable);
           return FALSE;
         }
 
@@ -126,6 +128,7 @@ peek_bytes (int            fd,
           g_set_error (error, G_IO_ERROR,
                        g_io_error_from_errno (errno),
                        "On recv command: %s", strerror (errno));
+          g_cancellable_release_fd (cancellable);
           return FALSE;
         }
 
@@ -207,6 +210,12 @@ peek_routing_token (int            fd,
                    "The TPKT Header doesn't have version 3");
       return FALSE;
     }
+  if (tpkt_length < 4 + 7)
+    {
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                   "The x224Crq TPDU length is too short");
+      return FALSE;
+    }
 
   /* Peek full PDU */
   Stream_Free (s, TRUE);
